@@ -8,7 +8,7 @@ import stat
 import sys
 from io import TextIOWrapper
 from pathlib import Path
-from typing import Any, Dict, Iterable, Iterator, List, Optional, Sequence
+from typing import Any, Dict, Iterable, Iterator, List, Optional, Sequence, Set
 from warnings import warn
 
 from . import __version__, api, sections
@@ -107,14 +107,25 @@ def sort_imports(
 
 def iter_source_code(paths: Iterable[str], config: Config, skipped: List[str]) -> Iterator[str]:
     """Iterate over all Python source files defined in paths."""
+    visited_dirs: Set[Path] = set()
+
     for path in paths:
         if os.path.isdir(path):
             for dirpath, dirnames, filenames in os.walk(path, topdown=True, followlinks=True):
                 base_path = Path(dirpath)
                 for dirname in list(dirnames):
-                    if config.is_skipped(base_path / dirname):
+                    full_path = base_path / dirname
+                    if config.is_skipped(full_path):
                         skipped.append(dirname)
                         dirnames.remove(dirname)
+
+                    resolved_path = full_path.resolve()
+                    if resolved_path in visited_dirs:  # pragma: no cover
+                        warn(f"Likely recursive symlink detected to {resolved_path}")
+                        dirnames.remove(dirname)
+                    else:
+                        visited_dirs.add(resolved_path)
+
                 for filename in filenames:
                     filepath = os.path.join(dirpath, filename)
                     if is_python_file(filepath):
@@ -555,8 +566,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="filter_files",
         action="store_true",
         help="Tells isort to filter files even when they are explicitly passed in as "
-        "part of the CLI command. Note that while this can be set as part of the config file it "
-        "only affects CLI operation.",
+        "part of the CLI command.",
     )
     parser.add_argument(
         "files", nargs="*", help="One or more Python source files that need their imports sorted."
@@ -615,6 +625,12 @@ def _build_arg_parser() -> argparse.ArgumentParser:
             " aliases to signify intent and change behaviour."
         ),
     )
+    parser.add_argument(
+        "--color",
+        dest="color_output",
+        action="store_true",
+        help="Tells isort to use color in terminal output.",
+    )
     parser.add_argument(
         "--float-to-top",
         dest="float_to_top",
